@@ -329,7 +329,7 @@ mozilla_remote_obtain_lock (Display *dpy, Window window)
   if (! lock_data)
     {
       lock_data = (char *) malloc (255);
-      g_snprintf (lock_data, 255, "pid%d@", getpid ());
+      g_snprintf (lock_data, 255, "pid%ld@", (long)getpid ());
 
       if (gethostname (lock_data + strlen (lock_data), 100))
 	{
