@@ -42,7 +42,9 @@ static void gnome_less_destroy (GtkObject *gl);
 
 static gint text_clicked_cb(GtkText * text, GdkEventButton * e, 
 			    GnomeLess * gl);
-
+static gboolean gnome_less_button_press_event (GtkText *text, GdkEventButton *button,
+					       gpointer data);
+					       
 static GtkWindowClass *parent_class;
 
 guint
@@ -86,21 +88,15 @@ gnome_less_init (GnomeLess *gl)
 {
   GtkWidget * vscroll;
   GtkWidget * hbox; /* maybe just inherit from hbox? hard to say yet. */
-  GtkWidget * mi;
 
   gl->text = GTK_TEXT(gtk_text_new(NULL, NULL));
 
   gl->font = NULL;
 
-  gl->popup = GTK_MENU(gtk_menu_new());
-  mi = gtk_menu_item_new_with_label("Doesn't do anything yet");
-  gtk_menu_append(gl->popup, mi);
-  gtk_widget_show(mi);
-
   gtk_widget_set_events(GTK_WIDGET(gl->text), GDK_BUTTON_PRESS_MASK);
   gtk_signal_connect(GTK_OBJECT(gl->text), "button_press_event",
-		     GTK_SIGNAL_FUNC(text_clicked_cb), gl);
-
+		     GTK_SIGNAL_FUNC(gnome_less_button_press_event), gl);
+		     
   hbox = gtk_hbox_new(FALSE, 0);
   vscroll = gtk_vscrollbar_new(gl->text->vadj);
   
@@ -526,18 +522,19 @@ void gnome_less_reshow          (GnomeLess * gl)
   g_free(contents);
 }
 
-static gint text_clicked_cb(GtkText * text, GdkEventButton * e, 
-			    GnomeLess * gl)
+static gboolean gnome_less_button_press_event (GtkText *text, GdkEventButton *button, gpointer data)
 {
-  if (e->button == 1) {
-    /* Ignore button 1 */
-    return TRUE; 
-  }
+	if (button->button == 4 || button->button == 5) {
+		GnomeLess *gl = GNOME_LESS (data);
+		GtkAdjustment *adj = GNOME_LESS (gl)->text->vadj;
+		gfloat new_value = adj->value + ((button->button == 4) ?
+						 - adj->page_increment / 2:
+						 adj->page_increment / 2);
+		new_value = CLAMP (new_value, adj->lower, adj->upper - adj->page_size);
+		gtk_adjustment_set_value (adj, new_value);
+		
+		return TRUE;
+	}
 
-  /* don't change the selection. */
-  gtk_signal_emit_stop_by_name (GTK_OBJECT (text), "button_press_event");
-
-  gtk_menu_popup(gl->popup, NULL, NULL, NULL,
-                 NULL, e->button, time(NULL));
-  return TRUE; 
+	return FALSE;
 }
